@@ -18,6 +18,12 @@
 
 # pylint: disable= no-member
 
+# pylint: disable= too-many-locals
+
+# pylint: disable= too-many-branches
+
+# pylint: disable= too-many-statements
+
 import argparse
 import os
 from fileinput import FileInput
@@ -103,9 +109,7 @@ def load():
         number = request.form.get('number')
         file = request.files.get('file')
 
-        print(file)
-
-        if year is None:
+        if year == '':
 
             message = 'Не указан год поступления'
             flash(message, category='error')
@@ -119,6 +123,9 @@ def load():
 
             return render_template("load.html")
 
+        group_lists = os.listdir(UPLOAD_FOLDER)
+        all_logins = []
+
         if file and allowed_file(file.filename):
 
             filename = f"{year}-{number}.txt"
@@ -137,6 +144,37 @@ def load():
 
             if load_list.read_slush(f"{UPLOAD_FOLDER}/{filename}")[0]:
 
+                for name in groups_lists:
+                    if name == '.DS_Store':
+                        group_lists.remove(name)
+
+                    if name != filename:
+
+                        with open(f"{UPLOAD_FOLDER}/{name}", 'r') as f_link:
+                            for line_all in f_link:
+                                login = line_all.split(';')[2]
+                                if login[-1] in ['\n', ' ']:
+                                    login = login[:-1]
+
+                                all_logins.append(login)
+
+                        with open(f"{UPLOAD_FOLDER}/{filename}", 'r') as fl_link:
+                            for line in fl_link:
+                                login_check = line.split(';')[2]
+                                if login_check[-1] in ['\n', ' ']:
+                                    login_check = login_check[:-1]
+
+                                if login_check in all_logins:
+                                    os.remove(f"{UPLOAD_FOLDER}/{filename}")
+
+                                    message = f"Пользователь с login -> {login_check} " \
+                                              f"уже существует. " \
+                                              f"Выберите другой."
+
+                                    flash(message, category='error')
+
+                                    return render_template("load.html")
+
                 group_name = load_list.load_slush()
                 groups_dir[group_name] = load_list
 
@@ -168,6 +206,12 @@ def load():
                     message = f"Некорректно указан fullname -> {error_name}." \
                               f"Исправьте на {access_name}"
 
+                elif load_list.read_slush(f"{UPLOAD_FOLDER}/{filename}")[2] == 'log':
+
+                    error_login = load_list.read_slush(f"{UPLOAD_FOLDER}/{filename}")[1]
+
+                    message = f"login {error_login} уже существует в этой группе. Выберите другой"
+
                 flash(message, category='error')
 
                 os.remove(f"{UPLOAD_FOLDER}/{filename}")
@@ -224,7 +268,8 @@ def slushlist(number):
                     continue
 
                 fio, fullname, login = line.split(';')
-                login = login[:-1]
+                if login[-1] in ['\n', ' ']:
+                    login = login[:-1]
                 del fio
 
                 slush.append(fullname)
@@ -304,26 +349,58 @@ def relogin():
 
             return render_template("relogin.html", group=group)
 
-        try:
-            groups_dir[number_group].relogin(old_login, new_login)
+        group_lists = os.listdir(UPLOAD_FOLDER)
+        all_logins = []
 
-            for line in FileInput(f"{UPLOAD_FOLDER}/{number_group}.txt", inplace=True):
-                login = line.split(';')
-                login[2] = login[2][:-1]
-                if login[2] == old_login:
-                    login[2] = new_login + '\n'
-                    line = ';'.join(login)
-                print(line, end='')
+        for name in group_lists:
+            if name != '.DS_Store':
 
-            message = 'Login изменен'
+                with open(f"{UPLOAD_FOLDER}/{name}", 'r') as f_link:
+                    for line in f_link:
+                        login = line.split(';')[2]
+                        if login[-1] in ['\n', ' ']:
+                            login = login[:-1]
 
-            flash(message, category='success')
+                        all_logins.append(login)
+
+        if new_login in all_logins:
+            message = f"Пользователь с login -> {new_login} " \
+                      f"уже существует. " \
+                      f"Выберите другой."
+
+            flash(message, category='error')
 
             return render_template("relogin.html", group=group)
 
+        try:
+            if groups_dir[number_group].relogin(old_login, new_login):
+
+                for line in FileInput(f"{UPLOAD_FOLDER}/{number_group}.txt", inplace=True):
+                    login = line.split(';')
+                    if login[2][-1] in ['\n', ' ']:
+                        login[2] = login[2][:-1]
+                    if login[2] == old_login:
+                        login[2] = new_login + '\n'
+                        line = ';'.join(login)
+                    print(line, end='')
+
+                message = 'Login изменен'
+
+                flash(message, category='success')
+
+                return render_template("relogin.html", group=group)
+
+            else:
+
+                message = "Новый логин уже существует"
+
+                flash(message, category='error')
+
+                return render_template("relogin.html", group=group)
+
         except ValueError:
 
-            message = "Введенный login отсутствует в списке"
+            message = f"Введенный login -> {old_login} отсутствует в списке"
 
             flash(message, category='error')
 
@@ -389,7 +466,8 @@ def rename():
 
                 for line in FileInput(f"{UPLOAD_FOLDER}/{number_group}.txt", inplace=True):
                     fullname = line.split(';')
-                    fullname[2] = fullname[2][:-1]
+                    if fullname[2][-1] in ['\n', ' ']:
+                        fullname[2] = fullname[2][:-1]
                     if fullname[2] == login:
                         fullname[1] = new_name
                         line = ';'.join(fullname) + '\n'
