@@ -176,7 +176,7 @@ class FlaskTestCase(unittest.TestCase):
         response = self.app.get('/load', content_type='html/text')
         self.assertEqual(response.status_code, 200)
 
-        response = self.load(None, '3', f"{UPLOAD_FOLDER}/2018-3.txt")
+        response = self.load('', '3', f"{UPLOAD_FOLDER}/2018-3.txt")
         self.assertIn('Не указан год поступления'.encode(), response.data)
 
         response = self.load('2018', '', f"{UPLOAD_FOLDER}/2018-3.txt")
@@ -195,7 +195,7 @@ class FlaskTestCase(unittest.TestCase):
         response = self.relogin('2018-3', 'nazarov', 'nazar_lex')
         self.assertIn('Login изменен'.encode(), response.data)
 
-        response = self.relogin('2018-3', 'nazarov', 'nazar_lex')
+        response = self.relogin('2018-3', 'nazarov', 'NAZAROV')
         self.assertIn('Введенный login отсутствует в списке'.encode(), response.data)
 
         response = self.relogin(None, 'nazar_lex', 'nazarov')
@@ -233,7 +233,8 @@ class FlaskTestCase(unittest.TestCase):
         self.assertIn('Неверно указан год поступления в новом fullname'.encode(), response.data)
 
         response = self.rename('2018-3', 'nazar_lex', '2018-4-33-naz')
-        self.assertIn('Неверно указан порядковый номер группы в новом fullname'.encode(), response.data)
+        self.assertIn('Неверно указан порядковый номер группы в '
+                      'новом fullname'.encode(), response.data)
 
     def test_delete_group(self):
         """Тестирование удаления группы в web-приложении"""
